pub fn subst_signature(
signature: LoadedFunctionInformation,
type_arguments: &[Type],
) -> VMResult<LoadedFunctionInformation>Expand description
substitutes the type arguments into the parameter and return types
pub fn subst_signature(
signature: LoadedFunctionInformation,
type_arguments: &[Type],
) -> VMResult<LoadedFunctionInformation>substitutes the type arguments into the parameter and return types